@@ -15,6 +15,8 @@ from . import test_cormap
 from . import test_autorg
 from . import test_bift
 from . import test_sasio
+from . import test_sas_argparser
+from . import test_fitting
 
 
 def suite():
@@ -26,9 +28,11 @@ def suite():
     testSuite.addTest(test_cormap.suite())
     testSuite.addTest(test_autorg.suite())
     testSuite.addTest(test_sasio.suite())
+    testSuite.addTest(test_sas_argparser.suite())
+    testSuite.addTest(test_fitting.suite())
     return testSuite
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     runner = unittest.TextTestRunner()
     runner.run(suite())
